#
# spec file for package meld
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           meld
Version:        3.22.3
Release:        1.1.2.1.sr20250101
Summary:        Visual diff and merge tool
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://meldmerge.org/
Source0:        https://download.gnome.org/sources/meld/3.22/%{name}-%{version}.tar.xz
BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
# Needed for typelib() Requires
BuildRequires:  gobject-introspection-devel
BuildRequires:  itstool
BuildRequires:  meson >= 0.49.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.48
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(gtksourceview-4) >= 4.0.0
BuildRequires:  pkgconfig(py3cairo) >= 1.15.0
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.30
BuildRequires:  pkgconfig(python3) >= 3.6
# needed for VCS diffs
Requires:       patch
Requires:       python3-cairo
Requires:       python3-gobject-Gdk
# the code obscures a lot of logic, instead of requiring GtkSource 4.0, they require
# GtkSource (any version) and then runtime complain if it's not 4.0 :( (boo#1184842)
Requires:       typelib(GtkSource) = 4
# Suggest various vcs that meld can handle
Suggests:       bzr
Suggests:       cvs
# Not in Factory, but still in OBS
Suggests:       darcs
Suggests:       fossil
Suggests:       git
Suggests:       mercurial
Suggests:       monotone
Suggests:       subversion
Suggests:       tla
#
BuildArch:      noarch

%description
Meld is a visual diff and merge tool. Two or three files can be
compared and be edited in place. (The diffs update dynamically). Two
or three directories can be compared and file comparisons be launched.
The working copy directory from version control systems such as CVS,
Subversion, Bazaar-ng and Mercurial can be browsed and viewed.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.gnome.Meld.appdata.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Meld.desktop

%files
%license COPYING
%doc NEWS
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/metainfo/org.gnome.Meld.appdata.xml
%{_datadir}/applications/org.gnome.Meld.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.meld.gschema.xml
%doc %{_datadir}/help/C/meld/
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/mime/packages/org.gnome.Meld.xml
%{_mandir}/man1/meld.1%{?ext_man}
%{python3_sitelib}/meld/

%files lang -f %{name}.lang

%changelog
* Wed Jan  8 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.22.3:
  + Fix custom label handling for folder and version-control views
  + Remove Ctrl+Page Up/Down bindings for horizontal scroll
  + Fix incorrect parent state in path label when opening new files
  + Don't use deprecated pipes module
  + Fix crash on blank folder comparison
  + Avoid loading MeldNotebook CSS provider multiple times
  + Fix pathbar not updating in folder comparisons
  + Updated translations.
* Mon Mar 25 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.22.2:
  + Fix incorrect DLL paths in Windows build.
  + Remove upstream deprecated 32-bit Windows build.
  + Updated translations.
* Sun Feb 18 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 3.22.1:
  + Work around layout sizing issue
  + Fix broken search context
  + Fix issues with pane contents swapping missing warnings and
  incorrectly handling blank or version-controlled panes
  + Fix go-to-line accelerator conflict with previous-conflict
  + Fix unintended requirement on Adwaita cursors
  + Fix incorrect cut/copy/paste sensitivity on pane change
  + Fix multi-row selection in folder and version control view
  + Fix missing pull/push version control icons
  + Refresh highlighting theme when dark theme preference changes
  + Remove filter and conflict buttons from new comparison tab
  + Fix scroll not working in file action gutter
  + Fix line number rendering when changing font sizes
  + Fix overview map not redrawing on text wrap toggle
  + Set minimum width for notebook labels
  + Improve notebook label ellipsization
  + Fix Meson byte-compilation support with DESTDIR
* Wed Sep  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.22.0:
  + Fix text filter changes on existing comparisons
  + Build fixes
  + Documentation updates
  + Updated translations.
- Drop meld-3.21.3-fix-executable-permission.patch: Fixed upstream.
* Thu Aug 25 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Add meld-3.21.3-fix-executable-permission.patch: Restore
  executable permission of application.
- Don't strip env from shebang line in %%prep: It's performed via
  meson since 3.21.3.
* Sun Aug 14 2022 Michael Ströder <michael@stroeder.com>
- Update to version 3.21.3:
  + Features:
  - Add shortcut for open externally action.
  - Add improved tooltips for tab labels.
  + Fixes:
  - Move horizontal-icon menu section to regular menu items.
  - Fix chunk navigation actions sometimes not working after
    chunk push/pull actions.
  - Show more parent context in path label display.
  - Update meson build to strip env from shebang line.
  - Fix left-click chunk actions under certain window managers.
  - Fix version control showing console windows on Windows.
  - Fix path label display for very long filenames.
* Sat Jun 18 2022 Michael Ströder <michael@stroeder.com>
- removed obsolete cc7746c141d976a4779cf868774fae1fe7627a6d.patch
- Update to version 3.21.2
  * Features:
  - Folder comparison now supports compare differently-named files across
    panes, by marking files for comparison (Helly Guo)
  - Synchronization points are now significantly easier to use and more
    robust, and have new user documentation (Roberto Vidal)
  - Added option to ignore Unicode normalisation form differences when
    comparing paths (Dan B)
  - The files or folders being compared can now be swapped in two pane mode,
    using the new View -> Swap left and right panes menu item (Helly Guo)
  - Folder comparisons now show a "(scanning...)" indication in tree view
    rows as an additional visual cue that the comparison is still running
    (Kai Willadsen)
  - Folder comparisons have a new optional ISO-format time column (Kai
    Willadsen)
  * Fixes:
  - Update icon usage to support stock icon removal from new Adwaita versions
    (Jan Tojnar)
  - Build fix for Meson 0.61.0 (Silvio Fricke)
  - The new pathlabel widgets now support user-provided custom labels (Kai
    Willadsen)
  - Fix file selectors in folder comparisons to always open in the current
    folder (Kai Willadsen)
  - Using a custom save path (i.e., the --output flag) now sets a buffer as
    modified, so that unchanged merges can be saved (Kai Willadsen)
  - Comparing new or deleted rows in folder comparison now opens a two-pane
    file comparisons for consistency (Kai Willadsen)
  - Destructive dialog actions now have appropriate styling (Kai Willadsen)
  - Invalid user settings for folder comparison columns are now handled more
    gracefully (Kai Willadsen)
  - The nightly flatpak build now includes Git to make version control
    comparisons somewhat functional (Kai Willadsen)
  - Issues fixed: #11, #85, #188, #319, #381, #475, #492, #581, #620, #638,
    [#645], #660, #662, #672
  * Improvements to translations
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add cc7746c141d976a4779cf868774fae1fe7627a6d.patch: Fix build
  with meson 0.61 and newer.
- Add appstream-glib and desktop-file-utils BuildRequires and add a
  check section, manually verifiy metainfo and desktop file during
  build, upstream does not yet provide a automated meson_test for
  this.
- Drop update-desktop-files BuildRequires and macro, no longer
  needed.
- Drop obsolete conditional shared-mime-info BuildRequires and
  glib2_gsettings_schema_requires macro, only needed for long out
  of support versions of openSUSE.
* Fri Jan  7 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.21.1:
  + UI changes:
  - A new custom per-pane location display widget replaces the
    standard GTK+ file chooser button and our existing
    placeholder path display, including actions for opening
    containing folder and copying file paths.
  - Version control comparison has had its action bar modernised
    in line with file and folder comparison.
  + Features:
  - The find bar now remembers the previous search across panes.
  - We show a warning to the user if they're trying to compare a
    file or folder to itself.
  - Meld no longer uses custom file chooser dialogs, improving
    portability and flatpak behaviour.
  - Two pane comparisons now allow Alt+Right/Left to work in
    either pane.
  - Certain header bar actions (e.g., conflict navigation,
    filters) are now only shown in their appropriate comparison
    types.
  - The application title no longer includes the per-comparison
    label.
  - Add a preference for GTK's dark theme support.
  - Retain clipboard contents after exiting Meld.
  + Updated translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Fri Apr 16 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add typelib(GtkSource) = 4 requires: The code obscures a lot of
  logic, instead of requiring GtkSource 4, they require GtkSource
  (any version) and then runtime complain if it's not 4.
  (boo#1184842).
* Mon Feb 15 2021 dimstar@opensuse.org
- Update to version 3.21.0:
  + Move to a modern GTK headerbar-based design.
  + Make file comparison change navigation more intuitive by
    changing how it decides where to scroll from.
  + Completely refreshed Meld application icon.
  + File comparison now has overscroll at the bottom of file
    comparisons, making it easier to see end-of-file differences
    and improving scroll syncing.
  + Text wrapping, whitespace, line numbers and line highlight can
    now all be toggled from the file comparison status bar.
  + Features:
  - Add support for CVS in version control comparisons.
  - Copy selected file paths in folder comparison.
  - Improve dark theme detection so custom Meld highlighting
    better matches the user's theme.
  + Fixes:
  - Fix file comparison closing after file save (Vasily Galkin)
  - Fix file comparison handling of certain line breaks (Kai Willadsen)
  + Internal changes:
  - Add Meson build system support.
  - Move from GtkUIManager to GAction-based actions
  - Move all UI-file-constructed widgets from custom Python
    wrapper classes to using real GtkWidget templates.
  - Move to new GtkSourceView 4 API.
  - Modernised Python GObject API usage, including signal and
    property usage.
  - Support Python 3.8.
  + Updated translations.
- Switch to meson buildsystem:
  + Add meson BuildRequires.
  + Use %%meson/%%meson_build/%%meson_install instead of
    python3 setup.py calls.
  + Drop hicolor-icon-theme, intltool, libxml2-tools and python3
    BuildRequires.
  + Add pkgconfig(glib-2.0), pkgconfig(gtk+-3.0),
    pkgconfig(gtksourceview-4), pkgconfig(py3cairo),
    pkgconfig(pygobject-3.0) and pkgconfig(python3) BuildRequires.
- Remove legacy post/postun scriptlets.
- Drop meld-nodocs.patch: no longer needed after the port to meson.
* Sat Feb 13 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.20.3:
  + Fix folder comparison sensitivity breaking when cancelling a
    scan.
  + Fix Subversion comparsion on Python 3.9.
  + Retain clipboard contents after exiting Meld.
  + Fix wrapping in notification bars.
  + Fix border width in our file selection dialog.
  + Fix occasional traceback when closing comparisons.
  + Update links to reflect move to Discourse.
  + Updated translations.
* Sun Feb 16 2020 bjorn.lie@gmail.com
- Update to version 3.20.2:
  + Fix display of large file sizes.
  + Set file chooser encoding to autodetect by default.
  + Fix ignoring blank lines on text-filtered files in folder
    comparison.
  + Fix expand/collapse actions for missing folders.
  + Fix some incorrect action sensitivity settings.
  + Fix height of commit dialog.
  + Fix install support for Python 3.8.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sun Mar 31 2019 Michael Ströder <michael@stroeder.com>
- Update to version 3.20.1:
  + Fix bad comparison highlighting with VT characters.
  + Fix folder comparison display with >2G files.
  + Fix support for missing folders in folder comparison.
  + Handle trash-related errors with NFS mounts.
  + Add release metadata to appstream data.
  + Issues fixed: glgo#GNOME/meld#268, glgo#GNOME/meld#295.
  + Updated translations.
* Sun Jan  6 2019 bjorn.lie@gmail.com
- Update to version 3.20.0:
  + Add Enter as a Compare accelerator in folder comparisons.
  + Change entry and drag-n-drop file changes to confirm discarding
    modified files instead of offering to save, for simplicity.
  + Fix menu sensitivity in folder comparisons.
  + Avoid dconf writes of no-op window size allocations.
  + Issues fixed: glgo#GNOME/meld#262, glgo#GNOME/meld#247.
  + Updated translations.
* Sun Dec 16 2018 astieger@suse.com
- Meld 3.19.1:
  + Support comparing remote files
  + Significantly improve folder comparison performance when
    comparing large trees
  + Improve folder comparison IO and memory use
  + Add recursive collapse/expand actions to folder comparisons
  + Add OARS metadata for software management
  + Support file drag-and-drop directly on to textviews
  + Refresh the application icon and add a processing pipeline
  + various bug fixes and translation updates
* Wed Mar 28 2018 luc14n0@linuxmail.org
- Update to version 3.19.0:
  + Features:
  - Add new per-pane status bar with selectors for syntax
    highlighting and text encoding;
  - Allow text encoding to be chosen from file selectors;
  - Add new go-to-line action and UI;
  - Folder comparison now explicitly indicates symlinks in the
    tree, and shows the symlink target;
  - Inline highlighting now draws whitespace in any changes it
    covers;
  - Navigating between changes in file comparison now briefly
    animates the outline, to make it easier to keep track of the
    focus in busy comparisons.
  + Fixes:
  - Handle file deletion where we can't move to trash (e.g.,
    network mounts);
  - Keybindings for notebook switching work again;
  - Threading fixes for more responsive highlighting and better
    exit handling;
  - Memory and file handle leakage for closed comparisons;
  - Make the --auto-compare and multiple --diff command line
    options work again;
  - Avoid a race condition that made the "Resolve conflict"
    prompt unreliable;
  - Invalid-iter crash when refreshing version control view;
  - Make non-existent files writable by default;
  + Bugs/issues fixed: bgo#589366, bgo#783989, bgo#785313,
    bgo#785630, bgo#786629, bgo#786867, bgo#787256, bgo#788455,
    bgo#788487, bgo#790335, bgo#791173, glgo#GNOME/meld#46,
    glgo#GNOME/meld#97, glgo#GNOME/meld#133, glgo#GNOME/meld#146,
    glgo#GNOME/meld#151, glgo#GNOME/meld#152, glgo#GNOME/meld#158,
    glgo#GNOME/meld#159, glgo#GNOME/meld#161, glgo#GNOME/meld#165.
  + Updated translations.
- Conditionalize shared-mime-info BuildRequires, glib2_gsettings_\
  schema_requires macro, and desktop_database_*, mime_database_*,
  glib2_gsettings_schema_* and icon_theme_cache_* post/postun
  scriptlets: only distribution releases where RPM 4.13 is not
  present still use them.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Oct 16 2017 dimstar@opensuse.org
- Add python3-cairo requires: Fix startup of the application
  (boo#1062151).
* Sun Sep 10 2017 jengelh@inai.de
- Rewrite description to put the package in focus.
* Sat Sep  9 2017 zaitor@opensuse.org
- Update to version 3.18.0:
  + Fix VC status not updating in some situations non-flattened
    mode.
  + Command line errors when invoking a secondary instance will no
    longer cause the second command to hang until the primary
    exits.
  + Bugs fixed: bgo#786629.
  + Updated translations.
* Wed Aug 16 2017 zaitor@opensuse.org
- Update to version 3.17.4:
  + Rebuild source tarball without spurious files.
- Drop obsolete clean section.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.17.3:
  + Fix folder compare when using text filters.
  + Make activity spinner show when inline comparisons are running.
  + Migrate back from threads to multiprocessing for inline diffs;
    unusual CPU contention caused this to harm interactivity.
  + Manually refreshing a file comparison sometimes caused diff
    navigation to break.
  + Folder comparisons that update their state no longer break
    navigation.
  + Version-control comparison on missing files now work again.
  + Fix regression in initial focus for folder comparisons.
  + Fix handling for added, partially staged files in git.
  + Bugs fixed: bgo#784436, bgo#785603, bgo#785859, bgo#786043.
  + Updated translations.
* Sun Jun 11 2017 zaitor@opensuse.org
- Update to version 3.17.2:
  + UI changes:
  - Significantly improve synchronisation of scroll bars between
    panes; we now try much harder to scroll all of a chunk on
    screen at the top and bottom of comparisons, and handle
    last-line-in-file cases better.
  - Place the cursor at the start of a replaced chunk instead of
    after it; this change should improve keyboard ergonomics when
    doing three-way merges, but does change our existing
    behaviour.
  - Remove Shift-based scroll locking; this was already broken by
    a GTK+ change, so this is just making it official.
  + Fixes:
  - Show correct column offset in status bar for tab indents.
  - Fix installation with a prefix for Python 3 changes.
  - Fix initial scroll-to-first-difference behaviour to avoid a
    race condition if the first change was on the first line.
  - Improve text wrapping behaviour in information bars, and
    avoid too-large allocations with long labels.
  - Work around infinite re-allocation problems and silence GTK+
    allocation warnings.
  - Fix bad UI state when closing a single-instance activated
    window.
  - Fix bad function call when using internal git conflict
    resolution.
  + Updated translations.
* Sat Mar 11 2017 dimstar@opensuse.org
- Update to version 3.17.1:
  + Features: Improve version checking, and try to show users a
    nice error dialog when  Meld's requirements aren't installed.
  + Fixes:
  - Help and documentation fixes.
  - Re-silence GTK+ logging with glib 2.46 structured logging
    changes.
  - Fix chunk deletion at EOF with CRLF endings.
  - Note filter performance effects in folder preferences.
  - Fix button alignment for new chunk action buttons.
  - Improve use of the newer emblem in folder comparison by
    showing it only when meaningful.
  - Fix crash caused by bad colour theme lookup.
  + Updated translations.
* Mon Jan  9 2017 dimstar@opensuse.org
- Update to version 3.17.0:
  + Port to python3:
  - Python 3 support; we now require Python 3.3 as a minimum.
  - Python 3 compatibility fixes; too many cases of bytes/string
    confusion, syntax changes and other miscellany to mention
    individually.
  - Handle new unicode-escape behaviour and unicode/bytes
    confusion for process interaction and version control
    plugins.
  - Add support for byte-based filters, to support directory vs.
    file comparison filters.
  + UI changes:
  - The "Tabs" menu item has been removed, to better match up
    with more modern GTK+ design. All of the actions are still
    available in the expected key bindings, and there is a new
    per-tab context menu.
  - The change action buttons in the central pane divider now
    correctly render as flat buttons.
  - The curves in the central pane divider are now... smoother!
  + Internal changes:
  - Handle reload notifications better in asynchronous saving.
  - Remove multi-process diff in favour of asynchronous
    (threaded, but GIL-throttled) matching.
  - Performance improvements in rendering of multiple widgets, as
    well as for initial text comparison.
  - Many updates for GTK+ 3.20 and 3.22 ABI changes.
  + Fixes:
  - Update supported version control list.
  - Update requirements and build requirements lists.
  - Don't create empty help/figures directories.
  + Updated translations.
- Update BuildRequires, Requires and Recommends in line with
  upstreams port to python3:
  + Removed: python, python-gconf, python-gobject-Gdk, python-gtk
    and python-gtksourceview.
  + Added: python3, python3-gobject-Gdk.
* Sun Dec 18 2016 zaitor@opensuse.org
- Update to version 3.16.4:
  + Make error displaying more robust with non-ASCII locales.
  + Handle themes with scrollbar steppers better.
  + Fix a traceback when pane has no file.
  + Fix triggering "Delete Change" actions from menu.
  + Handle style theme not existing.
  + Fix unintentional glib requirement bump.
  + Updated translations.
* Sun Sep 25 2016 zaitor@opensuse.org
- Update to version 3.16.3:
  + Fix bad scroll syncing and inability to move between comparison
    chunks in file comparisons.
  + Improve version control view behaviour when opening missing
    paths.
  + Fix saving of text created in blank comparison.
  + GTK+ 3.22 compatibility fixes for saving window size.
  + Fix formatted patches missing newlines in certain cases.
  + Silence GTK+ warning logging if not running in uninstalled
    (i.e. development) mode.
  + Update AppData.
  + Updated translations.
* Sat Jul 30 2016 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix performance regression in text filtering.
  + Fix regression in respecting custom text encoding.
  + Updated translations.
* Sun Jun 19 2016 zaitor@opensuse.org
- Update to version 3.16.1:
  + Fix regression in support for file comparisons from pipes.
  + Add open build service directories to the version control
    filter.
  + Add darcs to list of loaded plugins.
  + Fix the dark style.
  + Windows build fixes.
- Drop meld-add_osc_to_vcs_list.patch: Fixed upstream.
* Fri May 20 2016 alarrosa@suse.com
- Update to GNOME 3.20.2 (Fate#318572)
* Wed May 18 2016 mvetter@suse.com
- Add meld-add_osc_to_vcs_list.patch:
  + Add .osc folder to the list of files ignored as option 'VCS'.
* Sun May  1 2016 zaitor@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Sat Apr 23 2016 zaitor@opensuse.org
- Update to version 3.15.3:
  + Handle unicode dates in non-UTF8 locales in folder comparison.
  + Try to auto-detect when to use our dark theme highlighting.
  + After undo/redo actions in file comparisons, place the cursor
    at the natural edit position and scroll it back onscreen.
* Sat Apr 23 2016 michael@stroeder.com
- Require python-gobject-Gdk: pygobject was further split in order
  to be able to install it without X-dependencies. As meld is a
  GUI application, the dependency on the X-stack is no issue.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Mar 28 2016 zaitor@opensuse.org
- Update to version 3.15.2:
  + Port to use GtkSourceView's file loader and saver helpers,
    bringing several benefits.
  + Loading and saving speed are significantly improved, and are
    asychronous.
  + We try a wider range of locale-specific file encodings by
    default, and still support user-specified default encodings.
  + We now support saving files with inconsistent newline types.
  + Binary files will now be loaded on a best-effort basis.
  + Reinstate support for Darcs; this is currently limited to very
    new (>2.10.3) versions.
  + Folder comparisons now apply text filters in the same way as
    file comparisons.
  + Add support for showing new shortcuts help dialog.
  + Preliminary support for building Meld as an xdg-app.
  + Fixes:
  - Many fixes for GTK+ 3.20 theming changes and widget
    compatibility issues.
  - All accelerators should now consistently use the Primary key,
    for better integration on OSX systems.
  - Significantly improve text filter performance.
  - Fix performance regression where scanning for missing files
    was extremely slow, especially in large repositories.
  - Fix truncated line number display in short file.
  - Fix filter dropdown not appearing below button.
  - Add more documentation on setup and installation
    requirements.
  - Update the AppData to spec version 0.7+.
  + Updated translations.
* Sun Dec 20 2015 damjanovic.ivo@gmail.com
- Update to version 3.15.1:
  + Text ignored by filters is now dimmed to give some visual
    feedback that it's being ignored.
  + Text filters now apply independently, improving consistency;
    note that this is a behaviour change as filter order no longer
    matters, and filters will always apply to the original
    (not the filtered) text.
  + Recent menu items now show more detail in tooltips.
  + Update dialog action area layout for GTK+ theme changes.
  + Fixes:
  - Conflict resolution prompt now resolves properly again.
  - Silence some GTK+ assertions on window close.
  - Fix default filter issues from recent rework.
  - Percent-containing commit messages no longer corrupt
    our recent commit messages store.
  - Fix some problems with unicode user directories on Windows.
  - Fix encoding issues when saving files with load errors.
  - Fix drawing corruption when scrolling horizontally.
  - Fix clicking on the diffmap scrolling to the wrong location.
  - Fix off-by-one drawing error for final line in file.
  - Fix introspection requires to silence startup warnings.
  - Fix clearing syncpoints.
  - Add manual appdata kudos markers.
  - PEP8 fixes.
  + Updated translations.
- Rebase meld-nodocs.patch.
* Thu Dec 10 2015 zaitor@opensuse.org
- Update to version 3.14.2:
  + Fix some GTK+ assertions on window close.
  + Fix commit error with unicode commit messages.
  + Add manual appdata kudos markers.
  + Updated translations.
* Sun Oct  4 2015 zaitor@opensuse.org
- Update to version 3.14.1:
  + Features:
  - Offer to open binary files externally.
  - Use locale-based default encodings.
  + Fixes:
  - Fix crash with some GTK+ versions when using --output.
  - Fix merge-all action not working at all.
  - Fix creating patches with unicode path names.
  - Fix copy-to-clipboard option in patch dialog.
  - Fix diffmap alignment for new GTK+ allocation behaviour.
  - Improve float accuracy in folder comparison timestamp
    resolution.
  - Fix default SVN keyword filter to escape $ characters.
  - Fix display of unicode --help from command line.
  - Fix keyboard shortcut docs.
  - Don't incorrectly show identical notification for changed
    folder comparisons.
  + Updated translations.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.14.0:
  + Fix crash when starting folder comparison on Windows.
  + Fix bad chunk action behaviour for middle-to-right actions in
    three pane conflicts.
  + Documentation fixes.
  + Updated translations.
* Sun Jul 12 2015 zaitor@opensuse.org
- Update to version 3.13.3:
  + Fix syntax highlighting under Windows.
  + Update Windows build for newer pygi bundled libraries.
  + Fixes for incorrect descriptions in manual.
* Mon Jul  6 2015 zaitor@opensuse.org
- Update to version 3.13.2:
  + Several fixes for argument handling and tab creation:
  - Create --diff created comparisons after args-created ones.
  - Fix --label flag incorrectly applying to --diff created
    comparisons.
  - Create --diff created comparisons after args-created ones.
  - Fix relative path interpretation for --output when created
    from a secondary instance.
  - Fix window presentation ordering when creating a secondary
    instance.
  + Several fixes to unicode filename handling in git comparisons
    and manually-assigned labels.
  + Fix incorrect comparison display caused by unicode (U+2028)
    newline.
  + Fix not being able to activate some change bar actions by
    temporarily disabling overlay scrolling support on GTK+ 3.14.
  + Stop recreating duplicate recently-used file placeholders.
  + Fix out-of-date man page documentation.
  + Test fixes and testing improvements.
  + Documentation fixes.
  + Updated translations.
* Mon Jun  1 2015 fcrozat@suse.com
- SLE12 SP1 package (FATE#318492).
- Fix Url.
* Mon Apr 20 2015 astieger@suse.com
- Update to version 3.13.1:
  + Features:
  - more consistent comparison output when line endings differ:
    . Folder comparisons will now show an identical notification
    similar to the one used in file comparison.
    . The "New blank comparion" button now works for folder
    comparisons as well as file ones.
    . In folder comparisons, the expansion state of the tree is
    now remembered when you collapse and re-expand a row.
  + Fixes:
  - Better support icons in RTL locales.
  - Fixes for file encoding when saving with bad or missing
    encodings.
  - More consistent dialog handling and appearance.
  - Deprecation updates and compatibility fixes.
  - Fix bad comparison offset when multiple line breaks occurred
    on a single  line.
  - Unicode fixes for file change notifications.
  - Warnings (such as deprecation warnings) are now explicitly
    silenced in stable Meld.
  - Folder actions are now disabled while Meld is still scanning
    folders.
  - Fix some command line handling for ambiguous relative paths
    and invalid URIs.
  - Fix updating the comparison map when a file is updated within
    Meld.
- Rebase meld-nodocs.patch.
* Wed Dec 31 2014 zaitor@opensuse.org
- Update to version 3.13.0:
  + Features:
  - Make syntax highlighting style configurable.
  - Implemented incremental search, match highlighting and many
    other find-related fixes.
  - Add support for GTK+ global dark theme setting.
  - Add support for pushing change deletions.
  - Remove cycle-pane action in favour of previous/next pane
    actions.
  + Fixes:
  - Handle Unicode filenames in a git tree correctly.
  - Many fixes for recent GTK+ deprecation warnings.
  - Fixing flickering inline highlighting on updates.
  - Multiple work arounds for change colours not displaying on
    GTK+ 3.14.
  - Fix inconsistent file chooser when cancelling file selection.
  - UTF-8 encode patches created from the patch dialog.
  - Fix text-wrapping reset caused by the commit dialog.
  - Fix text background display on certain themes.
  - Fix for launching Meld with certain Git environment
    variables.
  - Add GTK's settings.ini file for font blurriness fix on
    Windows.
  - Fix display of change action buttons and line numbers when
    line numbers are shown.
  - Fix positioning of the change action buttons.
  - Fix tab width setting not working correctly.
  - Fix starting comparison of Subversion checkouts from a
    subdirectory.
  - Fix starting Meld from a differently-named symlink.
  - Ignore errors when copying file metadata if the destination
    file system doesn't support it.
  - Automatically recompile stale in-place gschemas.
  - Handle SIGINT to support previous quit-on-Ctrl-C behaviour.
  - Fix missing cache opcodes in some circumstance.
  - Fix text view expansion when resizing patch dialog.
  - Build fix to always include C locale when LINGUAS is set.
  + Updated translations.
* Tue Dec 30 2014 zaitor@opensuse.org
- Update to version 3.12.3:
  + Fix inconsistent file chooser when cancelling file selection.
  + UTF-8 encode patches created from the patch dialog.
  + Fix text-wrapping reset caused by the commit dialog.
  + Fix text background display on certain themes.
  + Fix for launching Meld with certain Git environment variables.
  + Add GTK's settings.ini file for font blurriness fix on Windows.
  + Updated translations.
- Drop meld-Dont-pass-git-env-vars.patch and
  meld-Repaint-TextView-background.patch: Fixed upstream.
* Thu Dec 18 2014 zaitor@opensuse.org
- Add meld-Dont-pass-git-env-vars.patch and
  meld-Repaint-TextView-background.patch from upstream. Fixes
  boo#909824.
* Thu Nov 13 2014 badshah400@gmail.com
- Update to version 3.12.2:
  + Fix display of change action buttons and line numbers when
    line numbers are shown
  + Fix positioning of the change action buttons
  + Fix tab width setting not working correctly
  + Fix starting comparison of Subversion checkouts from a
    subdirectory
  + Fix starting Meld from a differently-named symlink
  + Ignore errors when copying file metadata if the destination
    file system doesn't support it
  + Automatically recompile stale in-place gschemas
  + Handle SIGINT to support previous quit-on-Ctrl-C behaviour
  + Drop patches (incorporated upstream):
  - meld-ignore-error-when-copying-metadata.patch
  - meld-fix-tab-width-handling.patch
  - meld-starting-from-different-name-symlink.patch
  - meld-SIGINT-handler.patch.
* Mon Nov  3 2014 badshah400@gmail.com
- Add patches from upstream:
  + meld-fix-tab-width-handling.patch: fix GtkSourceView tab width
    property binding (bgo#738001)
  + meld-ignore-error-when-copying-metadata.patch: Ignore ENOTSUP
    when copying file metadata
  + meld-SIGINT-handler.patch: add a SIGINT signal handler for
    convenience (bgo#739719)
  + meld-starting-from-different-name-symlink.patch: allow
    starting Meld from differently-named symlink (bgo#739399)
* Sun Nov  2 2014 andreas.stieger@gmx.de
- Update to version 3.12.1:
  + Work around change colours not displaying on GTK+ 3.14.
  + Fix missing cache opcodes in some circumstances.
  + Fix text view expansion when resizing patch dialog.
  + Build fix to always include C locale when LINGUAS is set.
- Drop meld-format-as-patch-dialog-window.patch: fixed upstream.
* Thu Oct  9 2014 badshah400@gmail.com
- Add meld-format-as-patch-dialog-window.patch: fix vertical
  resizing of the format-as-patch dialog (bgo#738120).
* Sat Sep 27 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Fixes:
  - Ignore missing files when cleaning up our recently-used
    folder.
  - Guard against dialogs missing properties they should
    definitely have.
  - Remove old property from patch dialog.
  + Updated translations.
* Sat Sep 20 2014 zaitor@opensuse.org
- Update to version 3.11.4:
  + Fixes:
  - Only apply the auto merge flag to the last comparison
    started.
  - Fix install layout issues on Debian-based systems.
  - Fix "Open External" for files on Windows.
  - Record installation directory and executable location on
    Windows.
  - Revert to using latin1 as a fallback encoding; this will be
    reverted in the next unstable series.
  + Updated translations.
* Sat Aug 23 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + Features:
  - Manually handle app menu fallback for non-Gnome shells.
  - Save and restore window maximisation state.
  + Fixes:
  - Add missing/incomplete "Language" entries.
  - Miscellaneous code cleanups.
  - Handle broken locale settings better.
  - Fix size allocation issues in preferences UI.
  - Update shebang for environments with Python 3 as default.
  + Updated translations.
* Sun Jul 20 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Features:
  - File and folder comparison panes can now be resized.
  - Folder comparisons now support scrolling between chunks using
    the mouse wheel in the link map, like file comparisons.
  + Fixes:
  - Don't draw spurious actions for equal chunks.
  - Remove default sourceview behaviour for Alt+Left/Right.
  - Fix storing translated column names in configuration.
  - Several fixes for multiple windows in single-instance
    handling:
    . Resolve relative paths relative to the correct instance.
    . Don't create windows in the original instance when the
    calling instance errors out.
    . Raise the correct window for new windows in the same
    instance.
    . Exit correctly for command line errors in the calling
    instance.
  - Fix display of unicode paths in repositories.
  - Fix handling of unicode paths in recent files store.
  - Improve behaviour of Open External action, and handle spaces
    in filenames for the custom editor option.
  - Improve support custom installation prefixes.
- Changes from version 3.11.1:
  + Features:
  - New (alpha) infrastructure for stand-alone Windows builds.
  - Display renames and metadata in Bazaar repositories.
  - Improved tab labels in version control comparisons.
  - New merge-order preference to accompany comparison-order.
  - Added a prompt to mark a conflict as resolved from file
    comparison.
  + Fixes:
  - Fix filtering for shallow folder comparisons.
  - Several install and distribution fixes.
  - Sundry bug fixes.
  + Updated translations.
- Pass --no-update-icon-cache --no-compile-schemas to the distutils
  script.
* Sun Jul 20 2014 dimstar@opensuse.org
- Update to version 3.11.0:
  + Features:
  - Supporting hiding empty filtered folders in folder
    comparison.
  - Notify user when files change externally in file comparison.
  - Use standard GIO file trash handling when deleting files.
  - Newly written Mallard-based help.
  + User interface updates:
  - Support GNOME 3-style application menu.
  - Visual improvements to several icons.
  - Update Meld's colour scheme.
  - Many visual styling updates, layout tweaks and UI polish.
  + Internal changes:
  - Port to GObject introspection, GTK+ 3, GApplication,
    GSettings and other new things starting with 'G'.
  - Port to distutils, based on python-distutils-extra.
  - Move to using CSS for styling and colour definitions.
  - Update to use more modern GTK widgets.
  - Move a lot of extra UI construction into glade/UI files.
  - Make several custom icons themeable.
  - Make Meld a single-instance application, and add support for
    multiple windows.
  + Fixes:
  - Improved rendering speed in file comparisons.
  - Copy and paste within a buffer no longer causes occasional
    incorrect change highlighting.
  - Fixes for version control support.
  - Windows crash fixes.
  - Sundry bug fixes.
  + Updated translations.
- Drop meld-1.3.0-env.patch: no longer required.
- Add meld-nodocs.patch: do not install COPYING and NEWS: we do
  this on our own.
- Drop scrollkeeper BuildRequires: no longer needed.
- Add glib2-devel, gobject-introspection-devel, itstool and
  libxml2-tools BuildRequires: new requirements.
- Rewrite build and install section to match new upstream build
  system, based on distutils.
* Sat Jul 19 2014 zaitor@opensuse.org
- Update to version 1.8.6:
  + Handle spaces in filenames with external editor.
  + Fix storing translated column names in configuration.
  + Backport fix for "Open externally" sensitivity setting.
  + Fix support for fake comparisons in null VC.
  + Fix "Same" filter for shallow comparison cases.
  + Updated translations.
* Wed Jan 22 2014 dimstar@opensuse.org
- Update to version 1.8.4:
  + Fix crash when scanning CVS-only folders.
  + Fix crash on Windows when missing cdll.intl.
  + Fix crash with Italian (it_IT.utf8) locale.
  + Updated translations.
* Sun Dec 15 2013 zaitor@opensuse.org
- Update to version 1.8.3:
  + Fix subdirectory comparisons for Subversion 1.6.
  + Fix git status parsing for some statuses.
  + Don't disable updating when syncpoints aren't yet active.
  + Fix modifying column properties causing crashes when using .ini
    config backend.
  + Updated translations.
* Sun Oct 20 2013 zaitor@opensuse.org
- Update to version 1.8.2:
  + Fix regression selecting Subversion 1.6 repositories.
  + Fix for unicode usernames on Windows; note that this change
    also moves Meld config from the remote to the local app data
    folder.
  + Add copyright string to appdata file.
  + Updated translations.
* Sun Sep 22 2013 zaitor@opensuse.org
- Update to version 1.8.1:
  + Add AppData file.
  + Change order of version control selection for CVS and old SVN.
  + Fix escaped markup in folder comparisons.
  + Updated translations.
* Sun Sep 15 2013 firebird209@gmail.com
- Update to version 1.8.0:
  + Fixes: Minor fixes.
  + Updated translations.
* Tue Sep  3 2013 zaitor@opensuse.org
- Update to version 1.7.5:
  + Features:
  - Open the version control console view when the exit code of a
    VC operation indicates that there was an error.
  - Improve our handling of bad gconf setups, and add a
    file-system key to force a no-gconf fallback for persistent
    issues.
  - Add a preference for whether to highlight the current line of
    a file comparison.
  - Keyboard shortcut for the commit dialog.
  + Fixes:
  - Fix traversing symlink loops in version control comparisons.
  - Minor fixes and cleanups.
  + Updated translations.
* Sun Jul 28 2013 zaitor@opensuse.org
- Update to version 1.7.4:
  + Features:
  - Commit dialog can now automatically wrap commit messages.
  - Add Bazaar support for pushing changes, and improve
    sensitivity setting.
  - Support Subversion 1.8.
  - Type-ahead-find search now works in folder comparisons.
  - Preference to swap pane order left = local.
  - Arch, Codeville and RCS are no longer supported.
  + Fixes:
  - When opening new tabs from the command line, bring new tab to
    the front.
  - Current chunk highlight is now customisable using gtkrc.
  - Syncpoints now prevent chunks from being re-merged,
    syncpoints move with insertions, and disable automatic
    updating.
  - Various version control updates and fixes.
  - Sensitivity fixes.
  - Translation string fixes.
  + Updated translations.
* Thu Jun  6 2013 zaitor@opensuse.org
- Update to version 1.7.3:
  + Features:
  - Support launching conflict comparisons from Subversion.
  - The external text editor setting now supports opening files
    at a particular line number.
  - A host of minor improvements to the version control UI,
    including:
    . Add a new Push action for VC modules, currently supported
    in Git.
    . Show a summary of unpushed commits, currently supported in
    Git.
    . Reworked commit dialog, including more details about files
    to be committed and more useful previous-log selection.
    . Console output for VC comparisons is now formatted to
    better distinguish commands, output and errors.
    . Support better sensitivity handling in VC comparisons,
    currently implemented by Git.
  - Sundry minor UI improvements:
    . Much HIG-ification and better wording for actions, dialogs
    and labels.
    . Make columns user-resizable in version control and folder
    comparisons.
    . There is now a Save All action, to save all modified files
    in the current comparison.
    . Rather than giving up on long inline-highlighting
    comparisons, Meld now prompts to continue the comparison.
    . F5 is now a additional shortcut for Refresh.
    . Reload has been renamed to Revert and its UI has been
    improved for file comparisons.
  + Fixes:
  - Version control updates and miscellaneous fixes.
  - When guessing file types for syntax highlighting, we now use
    file contents as well as extension.
  - Prev/Next Change navigation now centres changes slightly more
    aggressively.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 1.7.2:
  + Features:
  - In version control view, conflicts now open in a three-way
    merge mode for Bazaar and Git, with other VCs to follow.
  - The "Ignore blank lines" setting is now used in folder
    comparisons, in same manner as text filters.
  + Fixes:
  - Many minor Windows compatibility fixes.
  - Version control compatibility updates and fixes.
  - Better handling of Unicode filenames.
  - Better support for cross-platform newline behaviour,
    particularly on Windows.
  - Sensitivity fixes for file and folder comparisons.
  - Build and installation fixes.
  + Updated translations.
- Drop meld-no-updates.patch: no longer needed when installing to
  DESTDIR.
* Fri Mar  1 2013 dimstar@opensuse.org
- Update to version 1.7.1:
  + Features:
  - Folder comparisons can now show extra information, such as
    file size and modification times. Column visibility and
    ordering are properly configurable.
  - Shallow comparison (i.e., based on size and timestamp) are
    now supported for folder comparisons, including timestamp
    resolution preferences for cross-filesystem comparisons.
  - The UI for launching new comparisons has been reworked to
    have a clearer workflow, and is now shown on startup if no
    other comparisons have been opened
  - Recently-used comparisons are now supported, allowing you to
    re-open previous comparisons directly.
  - Read-only files are now not editable by default, making merge
    actions clearer and more consistent. Individual read-only
    files can easily be set as editable as desired.
  + Bugfixes:
  - New version control API, currently used by Git and SVN
  - Version control compatibility updates and fixes
  - Command line labelling options now apply to folder tabs
  - Regressions from parallel inline highlighting calculations
    have been fixed
  - Diff algorithm cleanup
  - Compatibility fixes for Python 3; this does *not* mean that
    Meld works on Python 3 yet, just that 2to3 issues have been
    addressed
  + Updated translations.
- Add meld-no-updates.patch: do not execute update-mime-database
  and update-desktop-database during make install. We have to
  execute these on the target systems.
- Clean up spec-file, removing obsolete if's for old versions.
* Wed Nov  7 2012 dimstar@opensuse.org
- Update to version 1.7.0:
  + File comparisons are faster! Meld now has a smarter
    pre-processing step for inline highlighting of differences and
    does its highlighting calculations asynchronously, leading to
    better overall performance and interactivity.
  + Auto-merge mode is now available from the command-line.
  + Comparisons can be opened in new tabs (rather than in a new
    window) from the command line.
  + Custom colours can now be configured for all Meld drawing.
  + Improved behaviour when opening many tabs at once.
  + Notification of searches wrapping around the buffer.
  + Better compatibility with non-standard keyboard layouts.
  + Better error reporting for failed VC comparisons.
  + Version control compatibility updates and fixes.
  + Other miscellaneous bug fixes.
  + Updated translations.
* Sun Oct 21 2012 zaitor@opensuse.org
- Update to version 1.6.1:
  + Fix traceback from invalid tree cursor paths (rh#832969,
    rh#837133).
  + Fix traceback when popping up right-click menus in empty tree
    sections (rh#843879).
  + Fix Bazaar comparisons including exec bit changes (bgo#682852).
  + Avoid spurious listings in Bazaar with shelved items.
  + Fix copying symlinks in directories (rh#836606).
  + Support newer Fossil VC (bgo#683969).
  + Fix compatibility with Python 2.5.
* Sun Apr 29 2012 dimstar@opensuse.org
- Update to version 1.6.0:
  + Fix cursor location handling when our tree models change.
  + Updated translations.
* Tue Apr  3 2012 vuntz@opensuse.org
- Update to version 1.5.4:
  + Fixes:
  - Slightly faster diff calculation
  - Avoid too-tall commit dialogues
  - Minor bug fixes and performance improvements
  + Updated translations.
* Tue Jan 31 2012 dimstar@opensuse.org
- Update to version 1.5.3:
  + New features:
  - Add simple animations for chunk actions to make it easier to
    follow the result of insertion and deletion actions
  - Show the currently displayed page area in the side bars
  + Fixes:
  - Don't show links between chunks where one of the chunks is
    completely off-screen, reducing visual clutter
  - Syntax highlighting will now assume that all files in a
    comparison are of the same type if we can't determine
    otherwise
  - Some fixes to colour usage and legibility for dark themes,
    with more theme fixes coming soon
  - Remember active filters across sessions in directory and VC
    comparions
  - Guess which version control system a user is most likely to
    want to see, in the event of multiple VCs in a single working
    copy
  - Work with Subversion 1.7
  - Many sundry bug fixes
  + Updated translations.
- Add xz BuildRequires on openSUSE <= 12.1, in order to be able to
  decompress the xz-compressed tarball.
* Sun Jul 24 2011 vuntz@opensuse.org
- Update to version 1.5.2:
  + New features:
  - Add a new menu item and shortcut for switching between panes
    in file comparisons
  - Support type-ahead search in version control views
  + Fixes:
  - Non-editable files are now handled properly when doing
    sensitivity setting of change actions, and actions on the
    central change bar are presented accordingly
  - Fix incorrect comparison display in files containing FF or
    NEL linebreak literals
  - Updates to the Fossil version control support
  - Use faster validity check for Bazaar repositories
  - Many minor updates and other fixes
  + Updated translations.
- Add Suggests for various vcs that meld can deal with:
  + vcs available in openSUSE: bzr, cvs, git-core, mercurial,
    monotone, subversion.
  + vcs available in OBS: darcs, fossil, tla.
* Thu Jun  9 2011 vuntz@opensuse.org
- On 11.4 and later, change python-gnome Requires to python-gconf
  since this is the only module being used from python-gnome.
* Sun Mar 20 2011 dimstar@opensuse.org
- Update to version 1.5.1:
  + New features:
  - Add menu items and keyboard shortcuts for version control and
    directory comparison actions
  - Add support for the Fossil SCM
  - Add a menu for switching between tabs
  - Add a menu item to unlock scrolling
  + Code changes and fixes:
  - Improve filter handling with inline error reporting in the
    preference  pane, and correct refreshing of file and
    directory comparisons on filter changes
  - Make line number display work with GtkSourceView 2.10+
  - Support external diff tools in subversion
  - Support CVSNT as a CVS alternative
  - Performance fixes for subversion and bazaar
  - Correctly update a modified file's status in git and svn
    version control views
  - Make temporary files unwritable to avoid unintentionally
    editing them
  - Clean up diff results for cleaner comparisons
  - Improve symlink and binary handling, and error cases for
    directory comparisons
  - Improve copy semantics for directories and symlinks
  - Show case insensitivity and file encoding errors less
    intrusively
  - Sundry bug fixes
  + Updated translations.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 28 2010 dimstar@opensuse.org
- Update to version 1.5.0:
  + New features:
  - Use MyersSequenceMatcher by default
  - Add a "Show whitespace" preference
  - Add "Copy change above/below left/right" actions
  - Add Alt+Up/Down as shortcuts for previous/next change
  - Add previous/next conflict actions
  - Patch creation can now create reverse patches, and can choose
    between panes in a three-way comparison
  - Add a --output option for specifying where to save a merge
    result
  + Code changes and fixes:
  - Require Python 2.5, Gtk+/PyGtk 2.14, PyGtkSourceView 2.4
  - Port to gtk.Builder and gtk.IconTheme
  - Remove gnome-vfs usage
  - Portability fixes
  - Build fixes
  - Add a man page
  - Put preferences fallback in XDG-compliant location
  - Fix Undo/Redo with unicode text
  - Handle unicode linebreaks
  + Updated translations.
- Add python-gtksourceview Recommends and drop gnome-python-desktop
  Recommends.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 1.4.0:
  + Fix committing with RCS
  + Fix compatibility with old PyGObject
  + Updated translations.
* Thu Sep  9 2010 dimstar@opensuse.org
- Update to version 1.3.3:
  + Highlight currently focused change
  + Add ability to check if version control repos are valid
  + Support multiple-file undo/redo operations after save
  + Performance improvements, bug fixes and sundry contributions
  + Updated translations.
* Tue Jul 20 2010 ajorgensen@novell.com
- Update to 1.3.2
  + Add keyboard merging support
  + Add support for bulk change merging
  + Add auto-merge with ancestor mode; please note that this can
    currently only be started from the commandline
  + Updates to VC support, including lots of git fixes
  + UI cleanups, including a cleaner Preferences dialog, and
    message areas for most error reporting
  + Plenty of miscellaneous bug fixes
  + Translation updates
- Add patch Requires (needed for VCS diffs).
* Thu Apr  1 2010 vuntz@opensuse.org
- Clean up packaging from Contrib for inclusion in Factory:
  + Drop meld-1.3.0-desktop.patch and instead use options of
    suse_update_desktop_file.
  - Drop meld-1.3.0-scrollkeeper.patch: we need to remove the
    scrollkeeper files anyway.
  + Drop unneeded BuildRequires.
  + Make python-gnome a Requires instead of Recommends.
  + Improve description.
  + Split lang package.
* Wed Aug 19 2009 prusnak@suse.cz
- updated to 1.3.1
  * Add svk support (Vincent Legoll)
  * Add support for marking conflicts as resolved
    (Matthijs van de Water, Vincent Legoll)
  * Warp the text cursor to the start of jumped-to diff chunks
    (Vincent Legoll)
  * Allow toggling of toolbar and statusbar visibility, and add
    a fullscreen option (Michael Budde, Stephen Kennedy, Kai Willadsen)
  * Improved change merging and conflict resolution (Piotr Piastucki)
  * Speed up file comparisons and highlighting, significantly improving
    interactive editing performance (Kai Willadsen, Piotr Piastucki)
  * Meld has a shiny new application icon (Josef Vybíral)
* Wed Jun 10 2009 prusnak@suse.cz
- updated to 1.3.0
  * Minimum requirements are pygobject 2.8 and python 2.4
  * Find dialog replaced with find bar with replace functionality
  * Remove gnome dependencies (Kai Willadsen, Vincent Legoll)
  * Many ui tweaks and cleanups (Kai Willadsen, Vincent Legoll)
  * Support for multiple sourceview versions (Vincent Legoll)
  * Updated version control support
  * Multiple VCs in a single directory (Vincent Legoll)
  * Subversion 1.6.x (Vincent Legoll)
  * Add RCS support (Oliver Gerlich, Vincent Legoll)
  * Add Codeville support (Vincent Legoll)
* Mon Nov 24 2008 prusnak@suse.cz
- updated to 1.2.1
  * Pygtk version 2.8 now required
  * Port to gtk.UIManager (Kai Willadsen)
  * Handle spaces in svn paths (Neil Mayhew)
  * Command-line auto-compare all option on startup (Ondrej Novy)
  * Command-line can launch several comparisons (Brian Holmes)
  * Several UI tweaks (better focus behavior, better defaults)
- dropped obsolete patch:
  * ddir.patch (included in update)
* Thu Aug  7 2008 prusnak@suse.cz
- updated to 1.2
  * Improve tab rendering (Kai Willadsen)
  * Speedup folder comparison massively for large directories.
  * Fix crasher i18n bug (Kai Willadsen)
  * UI tweaks and cleanups (Tom Baugis, Kai Willadsen)
  * Cleanup vc library redundancy (Vincent Legoll)
  * Various version control fixes.
- applied fr-figures.patch from Andrew Jorgensen
* Wed Jul 25 2007 prusnak@suse.cz
- updated to 1.1.5
  * Handle new version contol command line arguments.
  * CLI option to set the tab labels. Bug 138860.
  * Improve mime type detection from Tomasz Bury. Bug 156137.
  * Hold shift when scrolling to scroll the panes independently.
  * File & folder history now saved from Sam Jacobson.
  * Several small ui improvements.
- changed '/usr/bin/env python' to '/usr/bin/python' (env.patch)
- dropped obsolete patch:
  * gettext.patch (included in update)
* Tue Apr  3 2007 prusnak@suse.cz
- test whether scrollkeeper-update exists (in post and postun scripts)
* Tue Feb 13 2007 prusnak@suse.cz
- created package (version 1.1.4) with patches:
  * meld-1.1.4-ddir.patch
  * meld-1.1.4-gettext.patch
  * meld-1.1.4-nonlocal.patch
  * meld-1.1.4-scrollkeeper.patch
